# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UpdateServiceGoalTemplate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UpdateServiceGoalTemplate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'service_level': 'BuServiceLevel',
            'average_speed_of_answer': 'BuAverageSpeedOfAnswer',
            'abandon_rate': 'BuAbandonRate',
            'metadata': 'WfmVersionedEntityMetadata'
        }

        self.attribute_map = {
            'name': 'name',
            'service_level': 'serviceLevel',
            'average_speed_of_answer': 'averageSpeedOfAnswer',
            'abandon_rate': 'abandonRate',
            'metadata': 'metadata'
        }

        self._name = None
        self._service_level = None
        self._average_speed_of_answer = None
        self._abandon_rate = None
        self._metadata = None

    @property
    def name(self):
        """
        Gets the name of this UpdateServiceGoalTemplate.
        The name of the service goal template.

        :return: The name of this UpdateServiceGoalTemplate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateServiceGoalTemplate.
        The name of the service goal template.

        :param name: The name of this UpdateServiceGoalTemplate.
        :type: str
        """
        
        self._name = name

    @property
    def service_level(self):
        """
        Gets the service_level of this UpdateServiceGoalTemplate.
        Service level targets for this service goal template

        :return: The service_level of this UpdateServiceGoalTemplate.
        :rtype: BuServiceLevel
        """
        return self._service_level

    @service_level.setter
    def service_level(self, service_level):
        """
        Sets the service_level of this UpdateServiceGoalTemplate.
        Service level targets for this service goal template

        :param service_level: The service_level of this UpdateServiceGoalTemplate.
        :type: BuServiceLevel
        """
        
        self._service_level = service_level

    @property
    def average_speed_of_answer(self):
        """
        Gets the average_speed_of_answer of this UpdateServiceGoalTemplate.
        Average speed of answer targets for this service goal template

        :return: The average_speed_of_answer of this UpdateServiceGoalTemplate.
        :rtype: BuAverageSpeedOfAnswer
        """
        return self._average_speed_of_answer

    @average_speed_of_answer.setter
    def average_speed_of_answer(self, average_speed_of_answer):
        """
        Sets the average_speed_of_answer of this UpdateServiceGoalTemplate.
        Average speed of answer targets for this service goal template

        :param average_speed_of_answer: The average_speed_of_answer of this UpdateServiceGoalTemplate.
        :type: BuAverageSpeedOfAnswer
        """
        
        self._average_speed_of_answer = average_speed_of_answer

    @property
    def abandon_rate(self):
        """
        Gets the abandon_rate of this UpdateServiceGoalTemplate.
        Abandon rate targets for this service goal template

        :return: The abandon_rate of this UpdateServiceGoalTemplate.
        :rtype: BuAbandonRate
        """
        return self._abandon_rate

    @abandon_rate.setter
    def abandon_rate(self, abandon_rate):
        """
        Sets the abandon_rate of this UpdateServiceGoalTemplate.
        Abandon rate targets for this service goal template

        :param abandon_rate: The abandon_rate of this UpdateServiceGoalTemplate.
        :type: BuAbandonRate
        """
        
        self._abandon_rate = abandon_rate

    @property
    def metadata(self):
        """
        Gets the metadata of this UpdateServiceGoalTemplate.
        Version metadata for the service goal template

        :return: The metadata of this UpdateServiceGoalTemplate.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this UpdateServiceGoalTemplate.
        Version metadata for the service goal template

        :param metadata: The metadata of this UpdateServiceGoalTemplate.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KnowledgeBase(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KnowledgeBase - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'core_language': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'faq_count': 'int',
            'date_document_last_modified': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'core_language': 'coreLanguage',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'faq_count': 'faqCount',
            'date_document_last_modified': 'dateDocumentLastModified',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._core_language = None
        self._date_created = None
        self._date_modified = None
        self._faq_count = None
        self._date_document_last_modified = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this KnowledgeBase.
        The globally unique identifier for the object.

        :return: The id of this KnowledgeBase.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KnowledgeBase.
        The globally unique identifier for the object.

        :param id: The id of this KnowledgeBase.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this KnowledgeBase.


        :return: The name of this KnowledgeBase.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this KnowledgeBase.


        :param name: The name of this KnowledgeBase.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this KnowledgeBase.
        Knowledge base description

        :return: The description of this KnowledgeBase.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this KnowledgeBase.
        Knowledge base description

        :param description: The description of this KnowledgeBase.
        :type: str
        """
        
        self._description = description

    @property
    def core_language(self):
        """
        Gets the core_language of this KnowledgeBase.
        Core language for knowledge base in which initial content must be created first

        :return: The core_language of this KnowledgeBase.
        :rtype: str
        """
        return self._core_language

    @core_language.setter
    def core_language(self, core_language):
        """
        Sets the core_language of this KnowledgeBase.
        Core language for knowledge base in which initial content must be created first

        :param core_language: The core_language of this KnowledgeBase.
        :type: str
        """
        allowed_values = ["en-US", "de-DE"]
        if core_language.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for core_language -> " + core_language)
            self._core_language = "outdated_sdk_version"
        else:
            self._core_language = core_language

    @property
    def date_created(self):
        """
        Gets the date_created of this KnowledgeBase.
        Knowledge base creation date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this KnowledgeBase.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this KnowledgeBase.
        Knowledge base creation date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this KnowledgeBase.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this KnowledgeBase.
        Knowledge base last modification date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this KnowledgeBase.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this KnowledgeBase.
        Knowledge base last modification date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this KnowledgeBase.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def faq_count(self):
        """
        Gets the faq_count of this KnowledgeBase.
        The count representing the number of documents of type FAQ per KnowledgeBase

        :return: The faq_count of this KnowledgeBase.
        :rtype: int
        """
        return self._faq_count

    @faq_count.setter
    def faq_count(self, faq_count):
        """
        Sets the faq_count of this KnowledgeBase.
        The count representing the number of documents of type FAQ per KnowledgeBase

        :param faq_count: The faq_count of this KnowledgeBase.
        :type: int
        """
        
        self._faq_count = faq_count

    @property
    def date_document_last_modified(self):
        """
        Gets the date_document_last_modified of this KnowledgeBase.
        The date representing when the last document is modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_document_last_modified of this KnowledgeBase.
        :rtype: datetime
        """
        return self._date_document_last_modified

    @date_document_last_modified.setter
    def date_document_last_modified(self, date_document_last_modified):
        """
        Sets the date_document_last_modified of this KnowledgeBase.
        The date representing when the last document is modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_document_last_modified: The date_document_last_modified of this KnowledgeBase.
        :type: datetime
        """
        
        self._date_document_last_modified = date_document_last_modified

    @property
    def self_uri(self):
        """
        Gets the self_uri of this KnowledgeBase.
        The URI for this object

        :return: The self_uri of this KnowledgeBase.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this KnowledgeBase.
        The URI for this object

        :param self_uri: The self_uri of this KnowledgeBase.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationSocialExpressionEventTopicChat(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationSocialExpressionEventTopicChat - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'room_id': 'str',
            'avatar_image_url': 'str',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'journey_context': 'QueueConversationSocialExpressionEventTopicJourneyContext',
            'wrapup': 'QueueConversationSocialExpressionEventTopicWrapup',
            'after_call_work': 'QueueConversationSocialExpressionEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'room_id': 'roomId',
            'avatar_image_url': 'avatarImageUrl',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'journey_context': 'journeyContext',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._id = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._room_id = None
        self._avatar_image_url = None
        self._held = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._journey_context = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationSocialExpressionEventTopicChat.


        :return: The state of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationSocialExpressionEventTopicChat.


        :param state: The state of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this QueueConversationSocialExpressionEventTopicChat.


        :return: The id of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationSocialExpressionEventTopicChat.


        :param id: The id of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._id = id

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationSocialExpressionEventTopicChat.


        :return: The provider of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationSocialExpressionEventTopicChat.


        :param provider: The provider of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationSocialExpressionEventTopicChat.


        :return: The script_id of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationSocialExpressionEventTopicChat.


        :param script_id: The script_id of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationSocialExpressionEventTopicChat.


        :return: The peer_id of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationSocialExpressionEventTopicChat.


        :param peer_id: The peer_id of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def room_id(self):
        """
        Gets the room_id of this QueueConversationSocialExpressionEventTopicChat.


        :return: The room_id of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this QueueConversationSocialExpressionEventTopicChat.


        :param room_id: The room_id of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._room_id = room_id

    @property
    def avatar_image_url(self):
        """
        Gets the avatar_image_url of this QueueConversationSocialExpressionEventTopicChat.


        :return: The avatar_image_url of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._avatar_image_url

    @avatar_image_url.setter
    def avatar_image_url(self, avatar_image_url):
        """
        Sets the avatar_image_url of this QueueConversationSocialExpressionEventTopicChat.


        :param avatar_image_url: The avatar_image_url of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        
        self._avatar_image_url = avatar_image_url

    @property
    def held(self):
        """
        Gets the held of this QueueConversationSocialExpressionEventTopicChat.


        :return: The held of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationSocialExpressionEventTopicChat.


        :param held: The held of this QueueConversationSocialExpressionEventTopicChat.
        :type: bool
        """
        
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationSocialExpressionEventTopicChat.


        :return: The disconnect_type of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationSocialExpressionEventTopicChat.


        :param disconnect_type: The disconnect_type of this QueueConversationSocialExpressionEventTopicChat.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationSocialExpressionEventTopicChat.


        :return: The start_hold_time of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationSocialExpressionEventTopicChat.


        :param start_hold_time: The start_hold_time of this QueueConversationSocialExpressionEventTopicChat.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationSocialExpressionEventTopicChat.


        :return: The connected_time of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationSocialExpressionEventTopicChat.


        :param connected_time: The connected_time of this QueueConversationSocialExpressionEventTopicChat.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationSocialExpressionEventTopicChat.


        :return: The disconnected_time of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationSocialExpressionEventTopicChat.


        :param disconnected_time: The disconnected_time of this QueueConversationSocialExpressionEventTopicChat.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationSocialExpressionEventTopicChat.


        :return: The journey_context of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: QueueConversationSocialExpressionEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationSocialExpressionEventTopicChat.


        :param journey_context: The journey_context of this QueueConversationSocialExpressionEventTopicChat.
        :type: QueueConversationSocialExpressionEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationSocialExpressionEventTopicChat.


        :return: The wrapup of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: QueueConversationSocialExpressionEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationSocialExpressionEventTopicChat.


        :param wrapup: The wrapup of this QueueConversationSocialExpressionEventTopicChat.
        :type: QueueConversationSocialExpressionEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationSocialExpressionEventTopicChat.


        :return: The after_call_work of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationSocialExpressionEventTopicChat.


        :param after_call_work: The after_call_work of this QueueConversationSocialExpressionEventTopicChat.
        :type: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationSocialExpressionEventTopicChat.


        :return: The after_call_work_required of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationSocialExpressionEventTopicChat.


        :param after_call_work_required: The after_call_work_required of this QueueConversationSocialExpressionEventTopicChat.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationSocialExpressionEventTopicChat.


        :return: The additional_properties of this QueueConversationSocialExpressionEventTopicChat.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationSocialExpressionEventTopicChat.


        :param additional_properties: The additional_properties of this QueueConversationSocialExpressionEventTopicChat.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UpdateDraftInput(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UpdateDraftInput - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'category': 'str',
            'name': 'str',
            'config': 'ActionConfig',
            'contract': 'ActionContractInput',
            'secure': 'bool',
            'version': 'int'
        }

        self.attribute_map = {
            'category': 'category',
            'name': 'name',
            'config': 'config',
            'contract': 'contract',
            'secure': 'secure',
            'version': 'version'
        }

        self._category = None
        self._name = None
        self._config = None
        self._contract = None
        self._secure = None
        self._version = None

    @property
    def category(self):
        """
        Gets the category of this UpdateDraftInput.
        Category of action, Can be up to 256 characters long

        :return: The category of this UpdateDraftInput.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this UpdateDraftInput.
        Category of action, Can be up to 256 characters long

        :param category: The category of this UpdateDraftInput.
        :type: str
        """
        
        self._category = category

    @property
    def name(self):
        """
        Gets the name of this UpdateDraftInput.
        Name of action, Can be up to 256 characters long

        :return: The name of this UpdateDraftInput.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateDraftInput.
        Name of action, Can be up to 256 characters long

        :param name: The name of this UpdateDraftInput.
        :type: str
        """
        
        self._name = name

    @property
    def config(self):
        """
        Gets the config of this UpdateDraftInput.
        Configuration to support request and response processing

        :return: The config of this UpdateDraftInput.
        :rtype: ActionConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this UpdateDraftInput.
        Configuration to support request and response processing

        :param config: The config of this UpdateDraftInput.
        :type: ActionConfig
        """
        
        self._config = config

    @property
    def contract(self):
        """
        Gets the contract of this UpdateDraftInput.
        Action contract

        :return: The contract of this UpdateDraftInput.
        :rtype: ActionContractInput
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """
        Sets the contract of this UpdateDraftInput.
        Action contract

        :param contract: The contract of this UpdateDraftInput.
        :type: ActionContractInput
        """
        
        self._contract = contract

    @property
    def secure(self):
        """
        Gets the secure of this UpdateDraftInput.
        Indication of whether or not the action is designed to accept sensitive data

        :return: The secure of this UpdateDraftInput.
        :rtype: bool
        """
        return self._secure

    @secure.setter
    def secure(self, secure):
        """
        Sets the secure of this UpdateDraftInput.
        Indication of whether or not the action is designed to accept sensitive data

        :param secure: The secure of this UpdateDraftInput.
        :type: bool
        """
        
        self._secure = secure

    @property
    def version(self):
        """
        Gets the version of this UpdateDraftInput.
        Version of current Draft

        :return: The version of this UpdateDraftInput.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this UpdateDraftInput.
        Version of current Draft

        :param version: The version of this UpdateDraftInput.
        :type: int
        """
        
        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class IntradayPlanningGroupRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntradayPlanningGroupRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'business_unit_date': 'date',
            'categories': 'list[str]',
            'planning_group_ids': 'list[str]',
            'interval_length_minutes': 'int'
        }

        self.attribute_map = {
            'business_unit_date': 'businessUnitDate',
            'categories': 'categories',
            'planning_group_ids': 'planningGroupIds',
            'interval_length_minutes': 'intervalLengthMinutes'
        }

        self._business_unit_date = None
        self._categories = None
        self._planning_group_ids = None
        self._interval_length_minutes = None

    @property
    def business_unit_date(self):
        """
        Gets the business_unit_date of this IntradayPlanningGroupRequest.
        Requested date in yyyy-MM-dd format. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The business_unit_date of this IntradayPlanningGroupRequest.
        :rtype: date
        """
        return self._business_unit_date

    @business_unit_date.setter
    def business_unit_date(self, business_unit_date):
        """
        Sets the business_unit_date of this IntradayPlanningGroupRequest.
        Requested date in yyyy-MM-dd format. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param business_unit_date: The business_unit_date of this IntradayPlanningGroupRequest.
        :type: date
        """
        
        self._business_unit_date = business_unit_date

    @property
    def categories(self):
        """
        Gets the categories of this IntradayPlanningGroupRequest.
        The metric categories

        :return: The categories of this IntradayPlanningGroupRequest.
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this IntradayPlanningGroupRequest.
        The metric categories

        :param categories: The categories of this IntradayPlanningGroupRequest.
        :type: list[str]
        """
        
        self._categories = categories

    @property
    def planning_group_ids(self):
        """
        Gets the planning_group_ids of this IntradayPlanningGroupRequest.
        The IDs of the planning groups for which to fetch data.  Omitting or passing an empty list will return all available planning groups

        :return: The planning_group_ids of this IntradayPlanningGroupRequest.
        :rtype: list[str]
        """
        return self._planning_group_ids

    @planning_group_ids.setter
    def planning_group_ids(self, planning_group_ids):
        """
        Sets the planning_group_ids of this IntradayPlanningGroupRequest.
        The IDs of the planning groups for which to fetch data.  Omitting or passing an empty list will return all available planning groups

        :param planning_group_ids: The planning_group_ids of this IntradayPlanningGroupRequest.
        :type: list[str]
        """
        
        self._planning_group_ids = planning_group_ids

    @property
    def interval_length_minutes(self):
        """
        Gets the interval_length_minutes of this IntradayPlanningGroupRequest.
        The period/interval in minutes for which to aggregate the data. Required, defaults to 15

        :return: The interval_length_minutes of this IntradayPlanningGroupRequest.
        :rtype: int
        """
        return self._interval_length_minutes

    @interval_length_minutes.setter
    def interval_length_minutes(self, interval_length_minutes):
        """
        Sets the interval_length_minutes of this IntradayPlanningGroupRequest.
        The period/interval in minutes for which to aggregate the data. Required, defaults to 15

        :param interval_length_minutes: The interval_length_minutes of this IntradayPlanningGroupRequest.
        :type: int
        """
        
        self._interval_length_minutes = interval_length_minutes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimMetadata(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimMetadata - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'resource_type': 'str',
            'last_modified': 'datetime',
            'location': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'resource_type': 'resourceType',
            'last_modified': 'lastModified',
            'location': 'location',
            'version': 'version'
        }

        self._resource_type = None
        self._last_modified = None
        self._location = None
        self._version = None

    @property
    def resource_type(self):
        """
        Gets the resource_type of this ScimMetadata.
        The type of SCIM resource.

        :return: The resource_type of this ScimMetadata.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this ScimMetadata.
        The type of SCIM resource.

        :param resource_type: The resource_type of this ScimMetadata.
        :type: str
        """
        allowed_values = ["User", "Group", "ServiceProviderConfig", "ResourceType", "Schema"]
        if resource_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for resource_type -> " + resource_type)
            self._resource_type = "outdated_sdk_version"
        else:
            self._resource_type = resource_type

    @property
    def last_modified(self):
        """
        Gets the last_modified of this ScimMetadata.
        The last time that the resource was modified. Date time is represented as an \"ISO-8601 string\", for example, yyyy-MM-ddTHH:mm:ss.SSSZ. Not included with \"Schema\" and \"ResourceType\" resources.

        :return: The last_modified of this ScimMetadata.
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """
        Sets the last_modified of this ScimMetadata.
        The last time that the resource was modified. Date time is represented as an \"ISO-8601 string\", for example, yyyy-MM-ddTHH:mm:ss.SSSZ. Not included with \"Schema\" and \"ResourceType\" resources.

        :param last_modified: The last_modified of this ScimMetadata.
        :type: datetime
        """
        
        self._last_modified = last_modified

    @property
    def location(self):
        """
        Gets the location of this ScimMetadata.
        The URI of the resource.

        :return: The location of this ScimMetadata.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this ScimMetadata.
        The URI of the resource.

        :param location: The location of this ScimMetadata.
        :type: str
        """
        
        self._location = location

    @property
    def version(self):
        """
        Gets the version of this ScimMetadata.
        The version of the resource. Matches the ETag HTTP response header. Not included with \"Schema\" and \"ResourceType\" resources.

        :return: The version of this ScimMetadata.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ScimMetadata.
        The version of the resource. Matches the ETag HTTP response header. Not included with \"Schema\" and \"ResourceType\" resources.

        :param version: The version of this ScimMetadata.
        :type: str
        """
        
        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuScheduleRun(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuScheduleRun - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'scheduler_run_id': 'str',
            'intraday_rescheduling': 'bool',
            'state': 'str',
            'week_count': 'int',
            'percent_complete': 'float',
            'target_week': 'date',
            'schedule': 'BuScheduleReference',
            'schedule_description': 'str',
            'scheduling_start_time': 'datetime',
            'scheduling_started_by': 'UserReference',
            'scheduling_canceled_by': 'UserReference',
            'scheduling_completed_time': 'datetime',
            'message_count': 'int',
            'rescheduling_options': 'ReschedulingOptionsRunResponse',
            'rescheduling_result_expiration': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'scheduler_run_id': 'schedulerRunId',
            'intraday_rescheduling': 'intradayRescheduling',
            'state': 'state',
            'week_count': 'weekCount',
            'percent_complete': 'percentComplete',
            'target_week': 'targetWeek',
            'schedule': 'schedule',
            'schedule_description': 'scheduleDescription',
            'scheduling_start_time': 'schedulingStartTime',
            'scheduling_started_by': 'schedulingStartedBy',
            'scheduling_canceled_by': 'schedulingCanceledBy',
            'scheduling_completed_time': 'schedulingCompletedTime',
            'message_count': 'messageCount',
            'rescheduling_options': 'reschedulingOptions',
            'rescheduling_result_expiration': 'reschedulingResultExpiration',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._scheduler_run_id = None
        self._intraday_rescheduling = None
        self._state = None
        self._week_count = None
        self._percent_complete = None
        self._target_week = None
        self._schedule = None
        self._schedule_description = None
        self._scheduling_start_time = None
        self._scheduling_started_by = None
        self._scheduling_canceled_by = None
        self._scheduling_completed_time = None
        self._message_count = None
        self._rescheduling_options = None
        self._rescheduling_result_expiration = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this BuScheduleRun.
        The globally unique identifier for the object.

        :return: The id of this BuScheduleRun.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BuScheduleRun.
        The globally unique identifier for the object.

        :param id: The id of this BuScheduleRun.
        :type: str
        """
        
        self._id = id

    @property
    def scheduler_run_id(self):
        """
        Gets the scheduler_run_id of this BuScheduleRun.
        The scheduler run ID.  Reference this value for support

        :return: The scheduler_run_id of this BuScheduleRun.
        :rtype: str
        """
        return self._scheduler_run_id

    @scheduler_run_id.setter
    def scheduler_run_id(self, scheduler_run_id):
        """
        Sets the scheduler_run_id of this BuScheduleRun.
        The scheduler run ID.  Reference this value for support

        :param scheduler_run_id: The scheduler_run_id of this BuScheduleRun.
        :type: str
        """
        
        self._scheduler_run_id = scheduler_run_id

    @property
    def intraday_rescheduling(self):
        """
        Gets the intraday_rescheduling of this BuScheduleRun.
        Whether this is an intraday rescheduling run

        :return: The intraday_rescheduling of this BuScheduleRun.
        :rtype: bool
        """
        return self._intraday_rescheduling

    @intraday_rescheduling.setter
    def intraday_rescheduling(self, intraday_rescheduling):
        """
        Sets the intraday_rescheduling of this BuScheduleRun.
        Whether this is an intraday rescheduling run

        :param intraday_rescheduling: The intraday_rescheduling of this BuScheduleRun.
        :type: bool
        """
        
        self._intraday_rescheduling = intraday_rescheduling

    @property
    def state(self):
        """
        Gets the state of this BuScheduleRun.
        The state of the generation run

        :return: The state of this BuScheduleRun.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this BuScheduleRun.
        The state of the generation run

        :param state: The state of this BuScheduleRun.
        :type: str
        """
        allowed_values = ["None", "Queued", "Scheduling", "Canceled", "Failed", "Complete"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def week_count(self):
        """
        Gets the week_count of this BuScheduleRun.
        The number of weeks spanned by the schedule

        :return: The week_count of this BuScheduleRun.
        :rtype: int
        """
        return self._week_count

    @week_count.setter
    def week_count(self, week_count):
        """
        Sets the week_count of this BuScheduleRun.
        The number of weeks spanned by the schedule

        :param week_count: The week_count of this BuScheduleRun.
        :type: int
        """
        
        self._week_count = week_count

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this BuScheduleRun.
        Percent completion of the schedule run

        :return: The percent_complete of this BuScheduleRun.
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this BuScheduleRun.
        Percent completion of the schedule run

        :param percent_complete: The percent_complete of this BuScheduleRun.
        :type: float
        """
        
        self._percent_complete = percent_complete

    @property
    def target_week(self):
        """
        Gets the target_week of this BuScheduleRun.
        The start date of the target week. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The target_week of this BuScheduleRun.
        :rtype: date
        """
        return self._target_week

    @target_week.setter
    def target_week(self, target_week):
        """
        Sets the target_week of this BuScheduleRun.
        The start date of the target week. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param target_week: The target_week of this BuScheduleRun.
        :type: date
        """
        
        self._target_week = target_week

    @property
    def schedule(self):
        """
        Gets the schedule of this BuScheduleRun.
        The generated schedule.  Null unless the schedule run is complete

        :return: The schedule of this BuScheduleRun.
        :rtype: BuScheduleReference
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this BuScheduleRun.
        The generated schedule.  Null unless the schedule run is complete

        :param schedule: The schedule of this BuScheduleRun.
        :type: BuScheduleReference
        """
        
        self._schedule = schedule

    @property
    def schedule_description(self):
        """
        Gets the schedule_description of this BuScheduleRun.
        The description of the generated schedule

        :return: The schedule_description of this BuScheduleRun.
        :rtype: str
        """
        return self._schedule_description

    @schedule_description.setter
    def schedule_description(self, schedule_description):
        """
        Sets the schedule_description of this BuScheduleRun.
        The description of the generated schedule

        :param schedule_description: The schedule_description of this BuScheduleRun.
        :type: str
        """
        
        self._schedule_description = schedule_description

    @property
    def scheduling_start_time(self):
        """
        Gets the scheduling_start_time of this BuScheduleRun.
        When the schedule generation run started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The scheduling_start_time of this BuScheduleRun.
        :rtype: datetime
        """
        return self._scheduling_start_time

    @scheduling_start_time.setter
    def scheduling_start_time(self, scheduling_start_time):
        """
        Sets the scheduling_start_time of this BuScheduleRun.
        When the schedule generation run started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param scheduling_start_time: The scheduling_start_time of this BuScheduleRun.
        :type: datetime
        """
        
        self._scheduling_start_time = scheduling_start_time

    @property
    def scheduling_started_by(self):
        """
        Gets the scheduling_started_by of this BuScheduleRun.
        The user who started the scheduling run

        :return: The scheduling_started_by of this BuScheduleRun.
        :rtype: UserReference
        """
        return self._scheduling_started_by

    @scheduling_started_by.setter
    def scheduling_started_by(self, scheduling_started_by):
        """
        Sets the scheduling_started_by of this BuScheduleRun.
        The user who started the scheduling run

        :param scheduling_started_by: The scheduling_started_by of this BuScheduleRun.
        :type: UserReference
        """
        
        self._scheduling_started_by = scheduling_started_by

    @property
    def scheduling_canceled_by(self):
        """
        Gets the scheduling_canceled_by of this BuScheduleRun.
        The user who canceled the scheduling run, if applicable

        :return: The scheduling_canceled_by of this BuScheduleRun.
        :rtype: UserReference
        """
        return self._scheduling_canceled_by

    @scheduling_canceled_by.setter
    def scheduling_canceled_by(self, scheduling_canceled_by):
        """
        Sets the scheduling_canceled_by of this BuScheduleRun.
        The user who canceled the scheduling run, if applicable

        :param scheduling_canceled_by: The scheduling_canceled_by of this BuScheduleRun.
        :type: UserReference
        """
        
        self._scheduling_canceled_by = scheduling_canceled_by

    @property
    def scheduling_completed_time(self):
        """
        Gets the scheduling_completed_time of this BuScheduleRun.
        When the scheduling run was completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The scheduling_completed_time of this BuScheduleRun.
        :rtype: datetime
        """
        return self._scheduling_completed_time

    @scheduling_completed_time.setter
    def scheduling_completed_time(self, scheduling_completed_time):
        """
        Sets the scheduling_completed_time of this BuScheduleRun.
        When the scheduling run was completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param scheduling_completed_time: The scheduling_completed_time of this BuScheduleRun.
        :type: datetime
        """
        
        self._scheduling_completed_time = scheduling_completed_time

    @property
    def message_count(self):
        """
        Gets the message_count of this BuScheduleRun.
        The number of schedule generation messages for this schedule generation run

        :return: The message_count of this BuScheduleRun.
        :rtype: int
        """
        return self._message_count

    @message_count.setter
    def message_count(self, message_count):
        """
        Sets the message_count of this BuScheduleRun.
        The number of schedule generation messages for this schedule generation run

        :param message_count: The message_count of this BuScheduleRun.
        :type: int
        """
        
        self._message_count = message_count

    @property
    def rescheduling_options(self):
        """
        Gets the rescheduling_options of this BuScheduleRun.
        Rescheduling options for this run.  Null unless intradayRescheduling is true

        :return: The rescheduling_options of this BuScheduleRun.
        :rtype: ReschedulingOptionsRunResponse
        """
        return self._rescheduling_options

    @rescheduling_options.setter
    def rescheduling_options(self, rescheduling_options):
        """
        Sets the rescheduling_options of this BuScheduleRun.
        Rescheduling options for this run.  Null unless intradayRescheduling is true

        :param rescheduling_options: The rescheduling_options of this BuScheduleRun.
        :type: ReschedulingOptionsRunResponse
        """
        
        self._rescheduling_options = rescheduling_options

    @property
    def rescheduling_result_expiration(self):
        """
        Gets the rescheduling_result_expiration of this BuScheduleRun.
        When the reschedule result will expire.  Null unless intradayRescheduling is true. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The rescheduling_result_expiration of this BuScheduleRun.
        :rtype: datetime
        """
        return self._rescheduling_result_expiration

    @rescheduling_result_expiration.setter
    def rescheduling_result_expiration(self, rescheduling_result_expiration):
        """
        Sets the rescheduling_result_expiration of this BuScheduleRun.
        When the reschedule result will expire.  Null unless intradayRescheduling is true. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param rescheduling_result_expiration: The rescheduling_result_expiration of this BuScheduleRun.
        :type: datetime
        """
        
        self._rescheduling_result_expiration = rescheduling_result_expiration

    @property
    def self_uri(self):
        """
        Gets the self_uri of this BuScheduleRun.
        The URI for this object

        :return: The self_uri of this BuScheduleRun.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this BuScheduleRun.
        The URI for this object

        :param self_uri: The self_uri of this BuScheduleRun.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBuScheduleRunTopicBuScheduleRun(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBuScheduleRunTopicBuScheduleRun - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'percent_complete': 'float',
            'intraday_rescheduling': 'bool',
            'state': 'str',
            'week_count': 'int',
            'schedule': 'WfmBuScheduleRunTopicBuScheduleReference',
            'scheduling_canceled_by': 'WfmBuScheduleRunTopicUserReference',
            'scheduling_completed_time': 'str',
            'message_count': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'percent_complete': 'percentComplete',
            'intraday_rescheduling': 'intradayRescheduling',
            'state': 'state',
            'week_count': 'weekCount',
            'schedule': 'schedule',
            'scheduling_canceled_by': 'schedulingCanceledBy',
            'scheduling_completed_time': 'schedulingCompletedTime',
            'message_count': 'messageCount'
        }

        self._id = None
        self._percent_complete = None
        self._intraday_rescheduling = None
        self._state = None
        self._week_count = None
        self._schedule = None
        self._scheduling_canceled_by = None
        self._scheduling_completed_time = None
        self._message_count = None

    @property
    def id(self):
        """
        Gets the id of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The id of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmBuScheduleRunTopicBuScheduleRun.


        :param id: The id of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: str
        """
        
        self._id = id

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The percent_complete of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this WfmBuScheduleRunTopicBuScheduleRun.


        :param percent_complete: The percent_complete of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: float
        """
        
        self._percent_complete = percent_complete

    @property
    def intraday_rescheduling(self):
        """
        Gets the intraday_rescheduling of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The intraday_rescheduling of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: bool
        """
        return self._intraday_rescheduling

    @intraday_rescheduling.setter
    def intraday_rescheduling(self, intraday_rescheduling):
        """
        Sets the intraday_rescheduling of this WfmBuScheduleRunTopicBuScheduleRun.


        :param intraday_rescheduling: The intraday_rescheduling of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: bool
        """
        
        self._intraday_rescheduling = intraday_rescheduling

    @property
    def state(self):
        """
        Gets the state of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The state of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this WfmBuScheduleRunTopicBuScheduleRun.


        :param state: The state of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: str
        """
        allowed_values = ["None", "Queued", "Scheduling", "Canceled", "Failed", "Complete"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def week_count(self):
        """
        Gets the week_count of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The week_count of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: int
        """
        return self._week_count

    @week_count.setter
    def week_count(self, week_count):
        """
        Sets the week_count of this WfmBuScheduleRunTopicBuScheduleRun.


        :param week_count: The week_count of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: int
        """
        
        self._week_count = week_count

    @property
    def schedule(self):
        """
        Gets the schedule of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The schedule of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: WfmBuScheduleRunTopicBuScheduleReference
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this WfmBuScheduleRunTopicBuScheduleRun.


        :param schedule: The schedule of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: WfmBuScheduleRunTopicBuScheduleReference
        """
        
        self._schedule = schedule

    @property
    def scheduling_canceled_by(self):
        """
        Gets the scheduling_canceled_by of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The scheduling_canceled_by of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: WfmBuScheduleRunTopicUserReference
        """
        return self._scheduling_canceled_by

    @scheduling_canceled_by.setter
    def scheduling_canceled_by(self, scheduling_canceled_by):
        """
        Sets the scheduling_canceled_by of this WfmBuScheduleRunTopicBuScheduleRun.


        :param scheduling_canceled_by: The scheduling_canceled_by of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: WfmBuScheduleRunTopicUserReference
        """
        
        self._scheduling_canceled_by = scheduling_canceled_by

    @property
    def scheduling_completed_time(self):
        """
        Gets the scheduling_completed_time of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The scheduling_completed_time of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: str
        """
        return self._scheduling_completed_time

    @scheduling_completed_time.setter
    def scheduling_completed_time(self, scheduling_completed_time):
        """
        Sets the scheduling_completed_time of this WfmBuScheduleRunTopicBuScheduleRun.


        :param scheduling_completed_time: The scheduling_completed_time of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: str
        """
        
        self._scheduling_completed_time = scheduling_completed_time

    @property
    def message_count(self):
        """
        Gets the message_count of this WfmBuScheduleRunTopicBuScheduleRun.


        :return: The message_count of this WfmBuScheduleRunTopicBuScheduleRun.
        :rtype: int
        """
        return self._message_count

    @message_count.setter
    def message_count(self, message_count):
        """
        Sets the message_count of this WfmBuScheduleRunTopicBuScheduleRun.


        :param message_count: The message_count of this WfmBuScheduleRunTopicBuScheduleRun.
        :type: int
        """
        
        self._message_count = message_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationScreenShareEventTopicWrapup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationScreenShareEventTopicWrapup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'code': 'str',
            'notes': 'str',
            'tags': 'list[str]',
            'duration_seconds': 'int',
            'end_time': 'datetime',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'code': 'code',
            'notes': 'notes',
            'tags': 'tags',
            'duration_seconds': 'durationSeconds',
            'end_time': 'endTime',
            'additional_properties': 'additionalProperties'
        }

        self._code = None
        self._notes = None
        self._tags = None
        self._duration_seconds = None
        self._end_time = None
        self._additional_properties = None

    @property
    def code(self):
        """
        Gets the code of this ConversationScreenShareEventTopicWrapup.


        :return: The code of this ConversationScreenShareEventTopicWrapup.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this ConversationScreenShareEventTopicWrapup.


        :param code: The code of this ConversationScreenShareEventTopicWrapup.
        :type: str
        """
        
        self._code = code

    @property
    def notes(self):
        """
        Gets the notes of this ConversationScreenShareEventTopicWrapup.


        :return: The notes of this ConversationScreenShareEventTopicWrapup.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this ConversationScreenShareEventTopicWrapup.


        :param notes: The notes of this ConversationScreenShareEventTopicWrapup.
        :type: str
        """
        
        self._notes = notes

    @property
    def tags(self):
        """
        Gets the tags of this ConversationScreenShareEventTopicWrapup.


        :return: The tags of this ConversationScreenShareEventTopicWrapup.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this ConversationScreenShareEventTopicWrapup.


        :param tags: The tags of this ConversationScreenShareEventTopicWrapup.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def duration_seconds(self):
        """
        Gets the duration_seconds of this ConversationScreenShareEventTopicWrapup.


        :return: The duration_seconds of this ConversationScreenShareEventTopicWrapup.
        :rtype: int
        """
        return self._duration_seconds

    @duration_seconds.setter
    def duration_seconds(self, duration_seconds):
        """
        Sets the duration_seconds of this ConversationScreenShareEventTopicWrapup.


        :param duration_seconds: The duration_seconds of this ConversationScreenShareEventTopicWrapup.
        :type: int
        """
        
        self._duration_seconds = duration_seconds

    @property
    def end_time(self):
        """
        Gets the end_time of this ConversationScreenShareEventTopicWrapup.


        :return: The end_time of this ConversationScreenShareEventTopicWrapup.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ConversationScreenShareEventTopicWrapup.


        :param end_time: The end_time of this ConversationScreenShareEventTopicWrapup.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationScreenShareEventTopicWrapup.


        :return: The additional_properties of this ConversationScreenShareEventTopicWrapup.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationScreenShareEventTopicWrapup.


        :param additional_properties: The additional_properties of this ConversationScreenShareEventTopicWrapup.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import apis into api package
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .architect_api import ArchitectApi
from .audit_api import AuditApi
from .authorization_api import AuthorizationApi
from .billing_api import BillingApi
from .chat_api import ChatApi
from .coaching_api import CoachingApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .data_extensions_api import DataExtensionsApi
from .external_contacts_api import ExternalContactsApi
from .fax_api import FaxApi
from .flows_api import FlowsApi
from .gamification_api import GamificationApi
from .general_data_protection_regulation_api import GeneralDataProtectionRegulationApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .integrations_api import IntegrationsApi
from .journey_api import JourneyApi
from .knowledge_api import KnowledgeApi
from .language_understanding_api import LanguageUnderstandingApi
from .languages_api import LanguagesApi
from .license_api import LicenseApi
from .locations_api import LocationsApi
from .mobile_devices_api import MobileDevicesApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .objects_api import ObjectsApi
from .organization_api import OrganizationApi
from .organization_authorization_api import OrganizationAuthorizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .scim_api import SCIMApi
from .scripts_api import ScriptsApi
from .search_api import SearchApi
from .speech_text_analytics_api import SpeechTextAnalyticsApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .telephony_api import TelephonyApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .textbots_api import TextbotsApi
from .tokens_api import TokensApi
from .uploads_api import UploadsApi
from .usage_api import UsageApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
from .web_chat_api import WebChatApi
from .widgets_api import WidgetsApi
from .workforce_management_api import WorkforceManagementApi



# coding: utf-8

"""
OrganizationAuthorizationApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class OrganizationAuthorizationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_orgauthorization_trustee(self, trustee_org_id, **kwargs):
        """
        Delete Org Trust
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orgauthorization_trustee(trustee_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orgauthorization_trustee" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `delete_orgauthorization_trustee`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_orgauthorization_trustee_user(self, trustee_org_id, trustee_user_id, **kwargs):
        """
        Delete Trustee User
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orgauthorization_trustee_user(trustee_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orgauthorization_trustee_user" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `delete_orgauthorization_trustee_user`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `delete_orgauthorization_trustee_user`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_orgauthorization_trustee_user_roles(self, trustee_org_id, trustee_user_id, **kwargs):
        """
        Delete Trustee User Roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orgauthorization_trustee_user_roles(trustee_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orgauthorization_trustee_user_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `delete_orgauthorization_trustee_user_roles`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `delete_orgauthorization_trustee_user_roles`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_orgauthorization_trustor(self, trustor_org_id, **kwargs):
        """
        Delete Org Trust
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orgauthorization_trustor(trustor_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustor Organization Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orgauthorization_trustor" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `delete_orgauthorization_trustor`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_orgauthorization_trustor_user(self, trustor_org_id, trustee_user_id, **kwargs):
        """
        Delete Trustee User
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orgauthorization_trustor_user(trustor_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustor Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orgauthorization_trustor_user" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `delete_orgauthorization_trustor_user`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `delete_orgauthorization_trustor_user`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}/users/{trusteeUserId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_pairing(self, pairing_id, **kwargs):
        """
        Get Pairing Info
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_pairing(pairing_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str pairing_id: Pairing Id (required)
        :return: TrustRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pairing_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_pairing" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'pairing_id' is set
        if ('pairing_id' not in params) or (params['pairing_id'] is None):
            raise ValueError("Missing the required parameter `pairing_id` when calling `get_orgauthorization_pairing`")


        resource_path = '/api/v2/orgauthorization/pairings/{pairingId}'.replace('{format}', 'json')
        path_params = {}
        if 'pairing_id' in params:
            path_params['pairingId'] = params['pairing_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustee(self, trustee_org_id, **kwargs):
        """
        Get Org Trust
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustee(trustee_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :return: Trustee
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustee" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `get_orgauthorization_trustee`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Trustee',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustee_user(self, trustee_org_id, trustee_user_id, **kwargs):
        """
        Get Trustee User
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustee_user(trustee_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: TrustUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustee_user" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `get_orgauthorization_trustee_user`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `get_orgauthorization_trustee_user`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUser',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustee_user_roles(self, trustee_org_id, trustee_user_id, **kwargs):
        """
        Get Trustee User Roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustee_user_roles(trustee_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: UserAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustee_user_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `get_orgauthorization_trustee_user_roles`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `get_orgauthorization_trustee_user_roles`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserAuthorization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustee_users(self, trustee_org_id, **kwargs):
        """
        The list of trustee users for this organization (i.e. users granted access to this organization).
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustee_users(trustee_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param int page_size: Page size
        :param int page_number: Page number
        :return: TrustUserEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'page_size', 'page_number']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustee_users" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `get_orgauthorization_trustee_users`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUserEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustees(self, **kwargs):
        """
        The list of trustees for this organization (i.e. organizations granted access to this organization).
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustees(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :return: TrustEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustees" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/orgauthorization/trustees'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustor(self, trustor_org_id, **kwargs):
        """
        Get Org Trust
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustor(trustor_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustor Organization Id (required)
        :return: Trustor
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustor" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `get_orgauthorization_trustor`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Trustor',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustor_user(self, trustor_org_id, trustee_user_id, **kwargs):
        """
        Get Trustee User
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustor_user(trustor_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustor Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: TrustUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustor_user" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `get_orgauthorization_trustor_user`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `get_orgauthorization_trustor_user`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}/users/{trusteeUserId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUser',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustor_users(self, trustor_org_id, **kwargs):
        """
        The list of users in the trustor organization (i.e. users granted access).
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustor_users(trustor_org_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustee Organization Id (required)
        :param int page_size: Page size
        :param int page_number: Page number
        :return: TrustUserEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id', 'page_size', 'page_number']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustor_users" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `get_orgauthorization_trustor_users`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUserEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orgauthorization_trustors(self, **kwargs):
        """
        The list of organizations that have authorized/trusted your organization.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orgauthorization_trustors(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :return: TrustorEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orgauthorization_trustors" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/orgauthorization/trustors'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustorEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_orgauthorization_pairings(self, body, **kwargs):
        """
        A pairing id is created by the trustee and given to the trustor to create a trust.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_orgauthorization_pairings(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TrustRequestCreate body: Pairing Info (required)
        :return: TrustRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_orgauthorization_pairings" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_orgauthorization_pairings`")


        resource_path = '/api/v2/orgauthorization/pairings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_orgauthorization_trustee_users(self, trustee_org_id, body, **kwargs):
        """
        Add a user to the trust.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_orgauthorization_trustee_users(trustee_org_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param TrustMemberCreate body: Trust (required)
        :return: TrustUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_orgauthorization_trustee_users" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `post_orgauthorization_trustee_users`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_orgauthorization_trustee_users`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUser',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_orgauthorization_trustees(self, body, **kwargs):
        """
        Create a new organization authorization trust. This is required to grant other organizations access to your organization.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_orgauthorization_trustees(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TrustCreate body: Trust (required)
        :return: Trustee
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_orgauthorization_trustees" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_orgauthorization_trustees`")


        resource_path = '/api/v2/orgauthorization/trustees'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Trustee',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_orgauthorization_trustees_audits(self, body, **kwargs):
        """
        Get Org Trustee Audits
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_orgauthorization_trustees_audits(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TrusteeAuditQueryRequest body: Values to scope the request. (required)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str sort_by: Sort by
        :param str sort_order: Sort order
        :return: AuditQueryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'page_size', 'page_number', 'sort_by', 'sort_order']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_orgauthorization_trustees_audits" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_orgauthorization_trustees_audits`")


        resource_path = '/api/v2/orgauthorization/trustees/audits'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AuditQueryResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_orgauthorization_trustor_audits(self, body, **kwargs):
        """
        Get Org Trustor Audits
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_orgauthorization_trustor_audits(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TrustorAuditQueryRequest body: Values to scope the request. (required)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str sort_by: Sort by
        :param str sort_order: Sort order
        :return: AuditQueryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'page_size', 'page_number', 'sort_by', 'sort_order']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_orgauthorization_trustor_audits" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_orgauthorization_trustor_audits`")


        resource_path = '/api/v2/orgauthorization/trustor/audits'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AuditQueryResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_orgauthorization_trustee(self, trustee_org_id, body, **kwargs):
        """
        Update Org Trust
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_orgauthorization_trustee(trustee_org_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param Trustee body: Client (required)
        :return: Trustee
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_orgauthorization_trustee" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `put_orgauthorization_trustee`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_orgauthorization_trustee`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Trustee',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_orgauthorization_trustee_user_roledivisions(self, trustee_org_id, trustee_user_id, body, **kwargs):
        """
        Update Trustee User Roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_orgauthorization_trustee_user_roledivisions(trustee_org_id, trustee_user_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :param RoleDivisionGrants body: Set of roles with corresponding divisions to apply (required)
        :return: UserAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_orgauthorization_trustee_user_roledivisions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `put_orgauthorization_trustee_user_roledivisions`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `put_orgauthorization_trustee_user_roledivisions`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_orgauthorization_trustee_user_roledivisions`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}/roledivisions'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserAuthorization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_orgauthorization_trustee_user_roles(self, trustee_org_id, trustee_user_id, body, **kwargs):
        """
        Update Trustee User Roles
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_orgauthorization_trustee_user_roles(trustee_org_id, trustee_user_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustee_org_id: Trustee Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :param list[str] body: List of roles (required)
        :return: UserAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustee_org_id', 'trustee_user_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_orgauthorization_trustee_user_roles" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustee_org_id' is set
        if ('trustee_org_id' not in params) or (params['trustee_org_id'] is None):
            raise ValueError("Missing the required parameter `trustee_org_id` when calling `put_orgauthorization_trustee_user_roles`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `put_orgauthorization_trustee_user_roles`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_orgauthorization_trustee_user_roles`")


        resource_path = '/api/v2/orgauthorization/trustees/{trusteeOrgId}/users/{trusteeUserId}/roles'.replace('{format}', 'json')
        path_params = {}
        if 'trustee_org_id' in params:
            path_params['trusteeOrgId'] = params['trustee_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserAuthorization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_orgauthorization_trustor_user(self, trustor_org_id, trustee_user_id, **kwargs):
        """
        Add a Trustee user to the trust.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_orgauthorization_trustor_user(trustor_org_id, trustee_user_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str trustor_org_id: Trustor Organization Id (required)
        :param str trustee_user_id: Trustee User Id (required)
        :return: TrustUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['trustor_org_id', 'trustee_user_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_orgauthorization_trustor_user" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'trustor_org_id' is set
        if ('trustor_org_id' not in params) or (params['trustor_org_id'] is None):
            raise ValueError("Missing the required parameter `trustor_org_id` when calling `put_orgauthorization_trustor_user`")
        # verify the required parameter 'trustee_user_id' is set
        if ('trustee_user_id' not in params) or (params['trustee_user_id'] is None):
            raise ValueError("Missing the required parameter `trustee_user_id` when calling `put_orgauthorization_trustor_user`")


        resource_path = '/api/v2/orgauthorization/trustors/{trustorOrgId}/users/{trusteeUserId}'.replace('{format}', 'json')
        path_params = {}
        if 'trustor_org_id' in params:
            path_params['trustorOrgId'] = params['trustor_org_id']
        if 'trustee_user_id' in params:
            path_params['trusteeUserId'] = params['trustee_user_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='TrustUser',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
